---
feature_story: FS_49_96_50_77
feature_title: config-only plugins
feature_status: TEST
---

Keywords: `config_only` `config_only_plugins`

Add config-only (demo) plugins:
*   loader
*   delegator

There are two main purposes:
*   Primary: provide simple manual examples which are easy to customize and explain in docs.
*   Secondary: target to make it easy to substitute Bash completion config by `argrelay` server config.

Data should be loaded from yaml directly without defining any enums in code or changing logic.

Launching local commands/scripts should be done via template parameterized by data envelope -
this should be doable as data load is controlled by the same config-only loader and delegator.
